# Generated by Django 3.2.11 on 2022-02-03 17:01

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('sap_success_factors', '0010_sapsuccessfactorsenterprisecustomerconfiguration_display_name'),
    ]

    operations = [
        migrations.AlterField(
            model_name='sapsuccessfactorslearnerdatatransmissionaudit',
            name='enterprise_course_enrollment_id',
            field=models.IntegerField(db_index=True),
        ),
    ]
